#region License
// Copyright (c) 2007 James Newton-King
//
// Permission is hereby granted, free of charge, to any person
// obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without
// restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following
// conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
#endregion

using System;
using System.Collections.Generic;
using System.Security.Cryptography;
using System.Text;
using Utilities.Testing;
using NUnit.Framework;
using Utilities.Miscellaneous;

namespace Utilities.Test.Miscellaneous
{
  public class EncryptionUtilsFixture : TestFixtureBase
  {
    [Test]
    public void EncryptAndDecrypt()
    {
      byte[] key = EncryptionUtils.GenerateKey();
      byte[] iv = EncryptionUtils.GenerateIV();

      byte[] encrypted = EncryptionUtils.Encrypt("test", key, iv);
      string decrypted = EncryptionUtils.Decrypt(encrypted, key, iv);

      Assert.AreEqual("test", decrypted);
    }

    [Test]
    public void GenerateKey()
    {
      byte[] key = EncryptionUtils.GenerateKey();

      Console.WriteLine("GenerateKey: " + Convert.ToBase64String(key));
      Assert.AreEqual(32, key.Length);
    }

    [Test]
    public void GenerateIV()
    {
      byte[] iv = EncryptionUtils.GenerateIV();

      Console.WriteLine("GenerateIV: " + Convert.ToBase64String(iv));
      Assert.AreEqual(16, iv.Length);
    }
  }
}