#region License
// Copyright (c) 2007 James Newton-King
//
// Permission is hereby granted, free of charge, to any person
// obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without
// restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following
// conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
#endregion

using System;
using NUnit.Framework;
using System.Reflection;
using System.ComponentModel;
using Utilities.Reflection;
using Utilities.Testing;

namespace Utilities.Test.Resources
{
  [TestResourceDescription("ResourceLoaderTestSimple")]
  public class ResourceDescriptionAttributeFixture : TestFixtureBase
  {
    [TestResourceDescription("ResourceLoaderTestSimple")]
    public string TestProperty
    {
      get { return "TestPropertyReturnValue"; }
    }

    [Test]
    public void DescriptionInstanceTest()
    {
      string result;

      TestResourceDescriptionAttribute attribute = new TestResourceDescriptionAttribute("ResourceLoaderTestSimple");
      result = attribute.Description;
      Assert.AreEqual("TestValue", result);
    }

    [Test]
    [TestResourceDescription("ResourceLoaderTestSimple")]
    public void DescriptionMemberAttributeTest()
    {
      string result;

      MemberInfo member = typeof(ResourceDescriptionAttributeFixture).GetMethod("DescriptionMemberAttributeTest");
 
      TestResourceDescriptionAttribute attribute = ReflectionUtils.GetAttribute<TestResourceDescriptionAttribute>(member);
      result = attribute.Description;
      Assert.AreEqual("TestValue", result);
    }

    [Test]
    [TestResourceDescription("ResourceLoaderTestSimple")]
    public void TypeDescriptorTest()
    {
      PropertyDescriptorCollection properties = TypeDescriptor.GetProperties(typeof(ResourceDescriptionAttributeFixture));
      PropertyDescriptor testProperty = properties["TestProperty"];

      Assert.AreEqual("TestValue", testProperty.Description);
    }

    [Test]
    [ExpectedException(typeof(Exception), ExpectedMessage = "Resource 'NotExistantResource' not found in Utilities.Test.Properties.Resources.")]
    public void DescriptionInstanceNotExistTest()
    {
      string result;

      TestResourceDescriptionAttribute attribute = new TestResourceDescriptionAttribute("NotExistantResource");
      result = attribute.Description;
      Assert.AreEqual("TestValue", result);
    }
  }
}